@@ -116,7 +116,8 @@ typedef enum {
     NM_META_COLOR_PERMISSION_UNKNOWN,
     NM_META_COLOR_PERMISSION_YES,
     NM_META_COLOR_PROMPT,
-    NM_META_COLOR_STATE_ASLEEP,
+    NM_META_COLOR_STATE_DISABLED,
+    NM_META_COLOR_STATE_ASLEEP = NM_META_COLOR_STATE_DISABLED, /* Deprecated */
     NM_META_COLOR_STATE_CONNECTED_GLOBAL,
     NM_META_COLOR_STATE_CONNECTED_LOCAL,
     NM_META_COLOR_STATE_CONNECTED_SITE,
